schema

package
v1.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 23, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AccessKey

type AccessKey struct {
	ent.Schema
}

AccessKey holds the schema definition for the AccessKey entity.

func (AccessKey) Edges

func (AccessKey) Edges() []ent.Edge

Edges of the AccessKey.

func (AccessKey) Fields

func (AccessKey) Fields() []ent.Field

Fields of the AccessKey.

func (AccessKey) Indexes

func (AccessKey) Indexes() []ent.Index

type Account

type Account struct {
	ent.Schema
}

Account holds the schema definition for the Account entity.

func (Account) Edges

func (Account) Edges() []ent.Edge

Edges of the Account.

func (Account) Fields

func (Account) Fields() []ent.Field

Fields of the Account.

func (Account) Indexes

func (Account) Indexes() []ent.Index

type DID

type DID struct {
	ent.Schema
}

DID holds the schema definition for the DID entity.

func (DID) Annotations

func (DID) Annotations() []schema.Annotation

Annotations of the DID.

func (DID) Edges

func (DID) Edges() []ent.Edge

Edges of the DID.

func (DID) Fields

func (DID) Fields() []ent.Field

Fields of the DID.

func (DID) Indexes

func (DID) Indexes() []ent.Index

type Identity

type Identity struct {
	ent.Schema
}

Identity holds the schema definition for the Identity entity.

func (Identity) Edges

func (Identity) Edges() []ent.Edge

Edges of the Identity.

func (Identity) Fields

func (Identity) Fields() []ent.Field

Fields of the Identity.

func (Identity) Indexes

func (Identity) Indexes() []ent.Index

type Locker

type Locker struct {
	ent.Schema
}

Locker holds the schema definition for the Locker entity.

func (Locker) Edges

func (Locker) Edges() []ent.Edge

Edges of the Locker.

func (Locker) Fields

func (Locker) Fields() []ent.Field

Fields of the Locker.

func (Locker) Indexes

func (Locker) Indexes() []ent.Index

type Property

type Property struct {
	ent.Schema
}

Property holds the schema definition for the Property entity.

func (Property) Edges

func (Property) Edges() []ent.Edge

Edges of the Property.

func (Property) Fields

func (Property) Fields() []ent.Field

Fields of the Property.

func (Property) Indexes

func (Property) Indexes() []ent.Index

type RecoveryCode

type RecoveryCode struct {
	ent.Schema
}

RecoveryCode holds the schema definition for the RecoveryCode entity.

func (RecoveryCode) Edges

func (RecoveryCode) Edges() []ent.Edge

Edges of the RecoveryCode.

func (RecoveryCode) Fields

func (RecoveryCode) Fields() []ent.Field

Fields of the RecoveryCode.

func (RecoveryCode) Indexes

func (RecoveryCode) Indexes() []ent.Index

Jump to